reader

package
v0.0.0-...-7234cf2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2025 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

The reader pkg is responsible for reading data from the store, building buckets from the data, and placing the buckets into a user-supplied channel.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Reader

type Reader struct {
	Inbox  chan *bucket.Bucket
	Outbox chan *bucket.Bucket
	Mchan  *metchan.Channel
	// contains filtered or unexported fields
}

func New

func New(cfg *conf.D, st store.Store) *Reader

Sets the scan interval to 1s.

func (*Reader) Start

func (r *Reader) Start(out chan *bucket.Bucket)

Jump to